@@ -1,19 +1,12 @@
-from __future__ import unicode_literals  # pragma: no cover
-from __future__ import print_function  # pragma: no cover
-
 # We have to use this entire file before we can turn coverage on, so we exclude
 # it from coverage.  We still have tests, though!
 
 import argparse  # pragma: no cover
-
-try:  # pragma: no cover
-    import configparser
-except:  # pragma: no cover
-    import ConfigParser as configparser
+import configparser  # pragma: no cover
 
 import coverage  # pragma: no cover
 
-coverage_version = "Coverage {}".format(coverage.__version__)  # pragma: no cover
+coverage_version = f"Coverage {coverage.__version__}"  # pragma: no cover
 
 import copy  # pragma: no cover
 import logging  # pragma: no cover
@@ -69,7 +62,7 @@ default_args = argparse.Namespace(  # pragma: no cover
 )
 
 
-class StoreOpt(object):  # pragma: no cover
+class StoreOpt:  # pragma: no cover
     """
     Helper class for storing lists of the options themselves to hand out to the
     shell completion scripts.
@@ -423,9 +416,7 @@ def parseArguments(argv=None):  # pragma: no cover
         )
     )
 
-    cov_args = parser.add_argument_group(
-        "Coverage Options ({})".format(coverage_version)
-    )
+    cov_args = parser.add_argument_group(f"Coverage Options ({coverage_version})")
     store_opt(
         cov_args.add_argument(
             "-r",
@@ -566,7 +557,7 @@ def parseArguments(argv=None):  # pragma: no cover
     return args
 
 
-class ConfigFile(object):  # pragma: no cover
+class ConfigFile:  # pragma: no cover
     """
     Filehandle wrapper that adds a "[green]" section to the start of a config
     file so that users don't actually have to manually add a [green] section.
